@@ -23,6 +23,8 @@
 #include "ui_savenewtheme.h"
 #include "managethemes.h"
 #include "ui_managethemes.h"
+#include "transdialog.h"
+#include "ui_transdialog.h"
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <QFileDialog>
 #include <QDirIterator>
@@ -88,8 +90,10 @@ private:
     managepresets* ManWin;
     savenewtheme* ThemeWin;
     managethemes* ManThemeWin;
+    transdialog* TranWin;
 
 private slots:
+    void on_pushButton_2_clicked();
     void on_Fonter_currentFontChanged(QFont f);
     void on_theme_currentIndexChanged(int index);
     void on_actionImport_theme_triggered();
