@@ -7,6 +7,16 @@ transdialog::transdialog(QWidget *parent) :
 {
     ui->setupUi(this);
     ui->scrollArea->setWidget(ui->widget);
+
+    if (!QFile::exists("/opt/theme-customizer/cssuinstalled")) {
+        ui->blurless->setDisabled(true);
+        ui->forcerotation->setDisabled(true);
+        ui->parallax->setDisabled(true);
+        ui->zaxis->setDisabled(true);
+        ui->tactile->setDisabled(true);
+        ui->taskswitcher->setDisabled(true);
+        ui->zoomonpress->setDisabled(true);
+    }
 //    readvalues();
 }
 
